<?php
class FrmProForm{

    function FrmProForm(){
        add_filter('frm_form_options_before_update', array(&$this, 'update_options'), 10, 2);
        add_action('frm_update_form', array(&$this, 'update'), 10, 2);
        add_filter('frm_validate_form', array(&$this, 'validate'), 10, 2);
    }
    
    function update_options($options, $values){
        global $frmpro_settings;
            
        $defaults = FrmProFormsHelper::get_default_opts();
        unset($defaults['logged_in']);
        unset($defaults['editable']);
        $defaults['inc_user_info'] = 0;
        
        foreach($defaults as $opt => $default)
            $options[$opt] = (isset($values['options'][$opt])) ? $values['options'][$opt] : $default;

        unset($defaults);
        
        $options['single_entry'] = (isset($values['options']['single_entry'])) ? 1 : 0;
        if ($options['single_entry'])
            $options['single_entry_type'] = (isset($values['options']['single_entry_type'])) ? $values['options']['single_entry_type'] : 'cookie';
            
        if (IS_WPMU)
            $options['copy'] = (isset($values['options']['copy'])) ? $values['options']['copy'] : 0;
        return $options;
    }
    
    function update($id, $values){
        global $wpdb, $frm_form, $frmdb, $frm_field;
        
        if (isset($values['options'])){
            $logged_in = isset($values['logged_in']) ? 1 : 0;
            $editable = isset($values['editable']) ? 1 : 0;
            $wpdb->update( $frmdb->forms, array('logged_in' => $logged_in, 'editable' => $editable), array( 'id' => $id ) );
        }
            
        //update dependent fields
        $all_fields = $frm_field->getAll("fi.form_id=$id");
        if ($all_fields){
            foreach($all_fields as $field){
                $option_array[$field->id] = maybe_unserialize($field->field_options);
                $option_array[$field->id]['type'] = $field->type;
                $option_array[$field->id]['dependent_fields'] = array();
                unset($field);
            }

            foreach($all_fields as $field){
                if(isset($option_array[$field->id]['hide_field']) and 
                    is_numeric($option_array[$field->id]['hide_field']) and
                    (!empty($option_array[$field->id]['hide_opt']) or !empty($option_array[$field->id]['form_select']))){
                    //save hidden fields to parent field
                    $parent_field = $option_array[$option_array[$field->id]['hide_field']];

                    if($parent_field){
                        $dep_fields = array();
                        if($option_array[$option_array[$field->id]['hide_field']]['type'] == 'data' and $field->type == 'data' and isset($option_array[$field->id]['form_select']) and is_numeric($option_array[$field->id]['form_select'])){
                            $dep_fields[] = $option_array[$field->id]['form_select'];
                            $dep_fields[] = $option_array[$field->id]['data_type'];
                        }else if(isset($option_array[$field->id]['hide_opt']) and !empty($option_array[$field->id]['hide_opt'])){
                            $dep_fields[] = $option_array[$field->id]['hide_opt'];
                        }

                        if(!empty($dep_fields))
                            $option_array[$option_array[$field->id]['hide_field']]['dependent_fields'][$field->id] = $dep_fields;
                    }
                }
                unset($field);
            }
            
            foreach($option_array as $field_id => $field_options){
                $frm_field->update($field_id, array('field_options' => $field_options));
                unset($field_options);
            }
            unset($option_array);
        }
    }

    function validate( $errors, $values ){
        global $frm_field;
        /*
        if (isset($values['item_meta'])){    
            foreach($values['item_meta'] as $key => $value){
                $field = $frm_field->getOne($key);  
                if ($field && $field->type == 'hidden' and empty($value))
                    $errors[] = __("Hidden fields must have a value.", 'formidable');
            }

        }
        */
          
        if (isset($values['logged_in']) or isset($values['editable']) or (isset($values['single_entry']) and isset($values['options']['single_entry_type']) and $values['options']['single_entry_type'] == 'user')){
            $form_id = $values['id'];
            $user_field = $frm_field->getAll("fi.form_id=$form_id and type='user_id'");
            if (!$user_field){
                $new_values = FrmFieldsHelper::setup_new_vars('user_id',$form_id);
                $new_values['name'] = __('User ID', 'formidable');
                $frm_field->create($new_values);
            }
        }
        
        if (isset($values['options']['auto_responder'])){
            if (!isset($values['options']['ar_email_message']) or $values['options']['ar_email_message'] == '')
                $errors[] = __("Please insert a message for your auto responder.", 'formidable');
            if (isset($values['options']['ar_reply_to']) and !is_email(trim($values['options']['ar_reply_to'])))
                $errors[] = __("That is not a valid reply-to email address for your auto responder.", 'formidable');
        }

        return $errors;
    }
    
    function has_field($type, $form_id, $single=true){
        global $frmdb;
        if($single)
            $included = $frmdb->get_one_record($frmdb->fields, compact('form_id', 'type'));
        else
            $included = $frmdb->get_records($frmdb->fields, compact('form_id', 'type'));
        return $included;
    }
    
    function post_type($form_id){
        if(is_numeric($form_id)){
            global $frmdb;
            $form_options = $frmdb->get_var($frmdb->forms, array('id' => $form_id), 'options');
            $form_options = maybe_unserialize($form_options);
            return (isset($form_options['post_type'])) ? $form_options['post_type'] : 'post';
        }else{
            $form = (array) $form_id;
            return (isset($form['post_type'])) ? $form['post_type'] : 'post';
        }
    }
}  
?>